@@ -1,12 +1,10 @@
 import timeit
-from telemetry import get_client
 
 
-class runtime:
-    
-    def __init__(self, report_name, service='statsd'):
-        self.service = service
+class Runtime:
+    def __init__(self, report_name, meter):
         self.report_name = report_name
+        self.meter = meter
 
     def __call__(self, fn):
         def wrapper_bench(*args, **kwargs):
@@ -18,27 +16,37 @@ class runtime:
 
             report_name = self.report_name
             if isinstance(report_name, type(lambda:1)):
-                report_name=self.report_name(*args, **kwargs)
+                report_name = self.report_name(*args, **kwargs)
 
-            get_client().timing(report_name, elapsed)
+            # get_client().timing(report_name, elapsed)
 
             return result
 
         return wrapper_bench
 
 
-class catch:
-
-    def __init__(self, report_name, service='airbrake'):
-        self.service = service
+class Catch:
+    def __init__(self, report_name, meter):
         self.report_name = report_name
+        self.meter = meter
 
     def __call__(self, fn):
         def wrapper_catch(*args, **kwargs):
             try:
                 return fn(*args, **kwargs)
             except Exception as err:
-                pass # IOU
+                self.meter.message(err)
                 raise err
 
         return wrapper_catch
+
+
+class Decorators:
+    def runtime(self, report_name):
+        """wrapper method for functions"""
+        return Runtime(report_name, self)
+
+    def catch(self, report_name):
+        """wrapper method for functions"""
+        return Catch(report_name, self)
+
